References
----------
.. [stevens1937] S. S. Stevens, J. Volkmann, and E. B. Newman, "A Scale for the
   Measurement of the Psychological Magnitude Pitch," The Journal of the
   Acoustical Society of America, vol. 8, no. 3, pp. 185-190, 1937.
.. [flanagan1960] J. L. Flanagan, "Models for approximating basilar membrane
   displacement," The Bell System Technical Journal, vol. 39, no. 5, pp.
   1163-1191, Sep. 1960.
.. [zwicker1961] E. Zwicker, "Subdivision of the Audible Frequency Range into
   Critical Bands (Frequenzgruppen)," The Journal of the Acoustical Society of
   America, vol. 33, no. 2, pp. 248-248, 1961.
.. [aertsen1981] A. M. H. J. Aertsen, J. H. J. Olders, and P. I. M. Johannesma,
   "Spectro-temporal receptive fields of auditory neurons in the grassfrog,"
   Biological Cybernetics, vol. 39, no. 3, pp. 195-209, Jan. 1981.
.. [oshaughnessy1987] D. O'Shaughnessy, Speech communication: human and
   machine. Addison-Wesley Pub. Co., 1987.
.. [traunmuller1990] H. Traunmüller, "Analytical expressions for the
   tonotopic sensory scale," The Journal of the Acoustical Society of America,
   vol. 88, no. 1, pp. 97-100, Jul. 1990.
.. [povey2011] D. Povey et al., "The Kaldi Speech Recognition Toolkit," in
   IEEE 2011 Workshop on Automatic Speech Recognition and Understanding, Hilton
   Waikoloa Village, Big Island, Hawaii, US, 2011.
.. [young] S. Young et al., "The HTK book (for HTK version 3.4)," Cambridge
   university engineering department, vol. 2, no. 2, pp. 2-3, 2006.